@@ -29,26 +29,12 @@ class DockerComposeClient:
         if cmd == "exec":
             exec_cmd = kwargs.pop("exec_cmd")
             return run_compose_cmd(*self._pre, cmd, *args, exec_cmd, *self._post, **kwargs)
+        elif 'no_services' in kwargs:
+            del kwargs['no_services']
+            return run_compose_cmd(*self._pre, cmd, *args, *self._post, **kwargs)
         else:
             return run_compose_cmd(*self._pre, cmd, *args, *self._services, *self._post, **kwargs)
 
-def get_docker_runtime(desired: str) -> str:
-    """Checks dockers available runtimes and will return desired if it's available
-
-    Args:
-        desired (str): The desired runtime, will return this if it's available
-
-    Returns:
-        str: Either the desired or the default docker runtime if desired is not an actual runtime
-    """
-    import re
-
-    stdout, _ = run_docker_cmd("--debug", "info", stdout=-1)
-    if re.search(f"Runtimes:.*{desired}", stdout) is not None:
-        return desired
-    else:
-        return re.search("Default Runtime: (.*)", stdout).group(1)
-
 def get_docker_client_binary_path() -> Optional[Path]:
     """Return the path of the docker client binary file.
 
@@ -153,33 +139,3 @@ def find_available_port(port, trys=5):
         else:
             break
     return port if not in_use else None
-
-# Devices
-def parse_devices(devices):
-    device_list = []
-    for device in devices:
-        if isinstance(device, dict):
-            device_list.append(device)
-            continue
-        if not isinstance(device, str):
-            raise errors.DockerException(
-                f'Invalid device type {type(device)}'
-            )
-        device_mapping = device.split(':')
-        if device_mapping:
-            path_on_host = device_mapping[0]
-            if len(device_mapping) > 1:
-                path_in_container = device_mapping[1]
-            else:
-                path_in_container = path_on_host
-            if len(device_mapping) > 2:
-                permissions = device_mapping[2]
-            else:
-                permissions = 'rwm'
-            device_list.append({
-                'PathOnHost': path_on_host,
-                'PathInContainer': path_in_container,
-                'CgroupPermissions': permissions,
-                'Original': device
-            })
-    return device_list
